# SPDX-License-Identifier: MIT
---
- name: Cluster with udp transport, full configuration
  hosts: all
  vars_files: vars/main.yml
  vars:
    ha_cluster_cluster_name: test-cluster
    ha_cluster_transport:
      type: udp
      options:
        - name: ip_version
          value: ipv4-6
        - name: netmtu
          value: 1024
      links:
        -
          - name: broadcast  # yamllint disable-line rule:hyphens
            value: 1
          - name: ttl
            value: 64
    ha_cluster_totem:
      options:
        - name: send_join
          value: 0
        - name: token_retransmits_before_loss_const
          value: 5
    ha_cluster_quorum:
      options:
        - name: auto_tie_breaker
          value: 1
        - name: wait_for_all
          value: 1

  tasks:
    - name: Run test
      tags: tests::verify
      block:
        - name: Set up test environment
          include_role:
            name: linux-system-roles.ha_cluster
            tasks_from: test_setup.yml

        - name: Run HA Cluster role
          include_role:
            name: linux-system-roles.ha_cluster
            public: true

        - name: Fetch cluster versions of cluster components
          include_tasks: tasks/fetch_versions.yml

        - name: Check corosync
          include_tasks: tasks/assert_corosync_config.yml
          vars:
            __test_expected_lines:
              - 'totem {'
              - '    version: 2'
              - '    cluster_name: {{ ha_cluster_cluster_name }}'
              - '    transport: udp'
              - '    send_join: 0'
              - '    token_retransmits_before_loss_const: 5'
              - '    ip_version: ipv4-6'
              - '    netmtu: 1024'
              - '    interface {'
              - '        broadcast: yes'
              - '        linknumber: 0'
              - '        ttl: 64'
              - '    }'
              - '}'
              - 'nodelist {'
              - '}'
              - 'quorum {'
              - '    provider: corosync_votequorum'
              - '    auto_tie_breaker: 1'
              - '    wait_for_all: 1'
              - '}'
              - 'logging {'
              - '    to_logfile: yes'
              - '    logfile: /var/log/cluster/corosync.log'
              - '    to_syslog: yes'
              - '    timestamp: on'
              - '}'

        - name: Check cluster status
          include_tasks: tasks/assert_cluster_running.yml

        - name: Check firewall and selinux state
          include_tasks: tasks/check_firewall_selinux.yml
